@@ -11,7 +11,7 @@ class instrument:
     def get_frame(self, exp_time):
         x = (self.x2 - self.x1) / self.xbin
         y = (self.y2 - self.y1) / self.ybin
-        return np.random.rand((x, y))
+        return np.random.rand(x, y)
 
     def roi(self, x1, x2, y1, y2):
         self.x1, self.x2, self.y1, self.y2 = x1, x2, y1, y2
